@@ -45,53 +45,52 @@ from lager.core import (
     warning,
 )
 
-
-__all__ = [
-    '__version__',
-    'LAGER_PORT',
-    'LOGURU_DEFAULT_FMT',
-    'TORNADO_FMT',
-    'loglevel',
-    'handlers',
-    'flog',
-    'logger',
-    'logging',
-    'lager',
-    'LAGER',
-    'LOG',
-    'log',
-    'ln',
-    'LN',
+__all__ = (
+    "__version__",
+    "LAGER_PORT",
+    "LOGURU_DEFAULT_FMT",
+    "TORNADO_FMT",
+    "loglevel",
+    "handlers",
+    "flog",
+    "logger",
+    "logging",
+    "lager",
+    "LAGER",
+    "LOG",
+    "log",
+    "ln",
+    "LN",
     #############
     ## HOISTED ##
     #############
-    '_change_activation',
-    '_core',
-    '_dynamic_level',
-    '_find_iter',
-    '_log',
-    '_options',
-    'add',
-    'bind',
-    'catch',
-    'complete',
-    'configure',
-    'contextualize',
-    'critical',
-    'debug',
-    'disable',
-    'enable',
-    'error',
-    'exception',
-    'info',
-    'level',
-    'opt',
-    'parse',
-    'patch',
-    'remove',
-    'start',
-    'stop',
-    'success',
-    'trace',
-    'warning',
-]
+    "_change_activation",
+    "_core",
+    "_dynamic_level",
+    "_find_iter",
+    "_log",
+    "_options",
+    "add",
+    "bind",
+    "catch",
+    "complete",
+    "configure",
+    "contextualize",
+    "critical",
+    "debug",
+    "disable",
+    "enable",
+    "error",
+    "exception",
+    "info",
+    "level",
+    "opt",
+    "parse",
+    "patch",
+    "remove",
+    "start",
+    "stop",
+    "success",
+    "trace",
+    "warning",
+)
