@@ -4,7 +4,6 @@ from typing import Any
 
 import httpx
 
-
 _SINKS = []
 
 
@@ -15,10 +14,10 @@ class HttpxSink(object):
         _SINKS.append(self)
 
     async def __call__(self, msg: Any) -> None:
-        httpx.post(self.url, data={'msg': msg})
+        httpx.post(self.url, data={"msg": msg})
 
     async def handle(self, message: Any) -> None:
-        await self.client.post(url=self.url, data={'msg': message})
+        await self.client.post(url=self.url, data={"msg": message})
 
     async def await_delete_channels(self) -> None:
         await self.client.aclose()
